
Test results
============

Failed tests: 0 of 15
	
Range selection tests
---------------------
:test-ok:`Comma separated numbers are parsed.`
:test-ok:`Accepts a comma followed by a space as delimiter.`
:test-ok:`Accepts a mix of commas and spaces as delimiter.`
:test-ok:`Exclusion is parsed.`
:test-ok:`Mixed ranges are parsed.`
:test-ok:`Raises exception on open python ranges.`
:test-ok:`Precedence is observed.`
:test-ok:`Python ranges are parsed.`
:test-ok:`Range is parsed.`
:test-ok:`Python stride syntax is accepted.`
:test-ok:`Single number is parsed.`
:test-ok:`Single exclusion is valid.`
:test-ok:`Result is sorted.`
:test-ok:`Space separated numbers are parsed.`
:test-ok:`Raises exception on invalid ranges.`



Invocation
----------

Run the test script on command line to get detailed error descriptions. Without the `debug` parameter, you will get reST output.

.. code:: sh

	f_tests.py debug

Documentation
-------------

.. automodule:: f_tests
   :members:
   :private-members:
   :special-members:
   :undoc-members:

	
